@@ -1,6 +1,6 @@
 /* FNA3D - 3D Graphics Library for FNA
  *
- * Copyright (c) 2020-2021 Ethan Lee
+ * Copyright (c) 2020-2022 Ethan Lee
  *
  * This software is provided 'as-is', without any express or implied warranty.
  * In no event will the authors be held liable for any damages arising from
@@ -134,7 +134,9 @@ typedef enum FNA3D_SurfaceFormat
 	FNA3D_SURFACEFORMAT_HDRBLENDABLE,
 	FNA3D_SURFACEFORMAT_COLORBGRA_EXT,
 	FNA3D_SURFACEFORMAT_COLORSRGB_EXT,
-	FNA3D_SURFACEFORMAT_DXT5SRGB_EXT
+	FNA3D_SURFACEFORMAT_DXT5SRGB_EXT,
+	FNA3D_SURFACEFORMAT_BC7_EXT,
+	FNA3D_SURFACEFORMAT_BC7SRGB_EXT,
 } FNA3D_SurfaceFormat;
 
 typedef enum FNA3D_DepthFormat
@@ -461,7 +463,7 @@ typedef struct FNA3D_RenderTargetBinding
 
 #define FNA3D_ABI_VERSION	 0
 #define FNA3D_MAJOR_VERSION	22
-#define FNA3D_MINOR_VERSION	 1
+#define FNA3D_MINOR_VERSION	 8
 #define FNA3D_PATCH_VERSION	 0
 
 #define FNA3D_COMPILED_VERSION ( \
@@ -500,7 +502,11 @@ FNA3DAPI void FNA3D_HookLogFunctions(
  */
 FNA3DAPI uint32_t FNA3D_PrepareWindowAttributes(void);
 
-/* After your window is created, call this to check for high-DPI support.
+/* After your device is created, call this to check for high-DPI support.
+ *
+ * Note that this will NOT work if it's called after the window is created but
+ * before the device! Not all platforms create drawable surfaces at the same
+ * time as the window!
  *
  * window:	The OS window handle, typically an SDL_Window*.
  * w:		Filled with the width of the window's drawable canvas.
@@ -1474,6 +1480,9 @@ FNA3DAPI uint8_t FNA3D_SupportsDXT1(FNA3D_Device *device);
 /* Returns 1 if the renderer natively supports S3TC texture data. */
 FNA3DAPI uint8_t FNA3D_SupportsS3TC(FNA3D_Device *device);
 
+/* Returns 1 if the renderer natively supports BC7 texture data. */
+FNA3DAPI uint8_t FNA3D_SupportsBC7(FNA3D_Device *device);
+
 /* Returns 1 if the renderer natively supports hardware instancing. */
 FNA3DAPI uint8_t FNA3D_SupportsHardwareInstancing(FNA3D_Device *device);
 
